/* ***** BEGIN LICENSE BLOCK *****
 * FW4SPL - Copyright (C) IRCAD, 2009-2015.
 * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
 * published by the Free Software Foundation.
 * ****** END LICENSE BLOCK ****** */

#ifndef __FWSERVICES_REGISTRY_NAMESPACE_HPP__
#define __FWSERVICES_REGISTRY_NAMESPACE_HPP__

namespace fwServices
{
/**
 * @brief       The namespace fwServices::registry contains class to manage services, object and config.
 * @namespace   fwServices::registry
 *
 * @date        2009-2010.
 *
 */
namespace registry
{

}
}
#endif /* __FWSERVICES_REGISTRY_NAMESPACE_HPP__ */
